@@ -35,6 +35,7 @@ from tests.markers import MARKER_WINDOWS
 
 
 if TYPE_CHECKING:
+    from collections.abc import Collection
     from pathlib import Path
 
     from packaging.utils import NormalizedName
@@ -54,7 +55,7 @@ class Locker(BaseLocker):
         return self
 
     def mock_lock_data(self, data: dict[str, Any]) -> None:
-        self._lock_data = data  # type: ignore[assignment]
+        self._lock_data = data
 
     def is_locked(self) -> bool:
         return self._locked
@@ -889,22 +890,6 @@ foo==1.2.3 ; {MARKER_PY} \\
 @pytest.mark.parametrize(
     ["extras", "lines"],
     [
-        (
-            None,
-            [f"foo==1.2.3 ; {MARKER_PY}"],
-        ),
-        (
-            False,
-            [f"foo==1.2.3 ; {MARKER_PY}"],
-        ),
-        (
-            True,
-            [
-                f"bar==4.5.6 ; {MARKER_PY}",
-                f"foo==1.2.3 ; {MARKER_PY}",
-                f"spam==0.1.0 ; {MARKER_PY}",
-            ],
-        ),
         (
             ["feature-bar"],
             [
@@ -918,7 +903,7 @@ foo==1.2.3 ; {MARKER_PY} \\
 def test_exporter_exports_requirements_txt_with_optional_packages(
     tmp_path: Path,
     poetry: Poetry,
-    extras: bool | list[NormalizedName] | None,
+    extras: Collection[NormalizedName],
     lines: list[str],
 ) -> None:
     poetry.locker.mock_lock_data(  # type: ignore[attr-defined]
@@ -1130,6 +1115,43 @@ foo==1.2.3 ; {MARKER_PY}
     assert content == expected
 
 
+def test_exporter_can_export_requirements_txt_with_circular_root_dependency(
+    tmp_path: Path, poetry: Poetry
+) -> None:
+    poetry.locker.mock_lock_data(  # type: ignore[attr-defined]
+        {
+            "package": [
+                {
+                    "name": "foo",
+                    "version": "1.2.3",
+                    "category": "main",
+                    "optional": False,
+                    "python-versions": "*",
+                    "dependencies": {poetry.package.pretty_name: {"version": "1.2.3"}},
+                },
+            ],
+            "metadata": {
+                "python-versions": "*",
+                "content-hash": "123456789",
+                "files": {"foo": []},
+            },
+        }
+    )
+    set_package_requires(poetry)
+
+    exporter = Exporter(poetry, NullIO())
+    exporter.export("requirements.txt", tmp_path, "requirements.txt")
+
+    with (tmp_path / "requirements.txt").open(encoding="utf-8") as f:
+        content = f.read()
+
+    expected = f"""\
+foo==1.2.3 ; {MARKER_PY}
+"""
+
+    assert content == expected
+
+
 def test_exporter_can_export_requirements_txt_with_nested_packages_and_multiple_markers(
     tmp_path: Path, poetry: Poetry
 ) -> None:
@@ -2154,7 +2176,7 @@ def test_exporter_doesnt_confuse_repeated_packages(
     io = BufferedIO()
     exporter.export("requirements.txt", tmp_path, io)
 
-    expected = f"""\
+    expected_legacy = f"""\
 celery==5.1.2 ; {MARKER_PY36_ONLY}
 celery==5.2.3 ; {MARKER_PY37}
 click-didyoumean==0.0.3 ; {MARKER_PY36_PY362}
@@ -2164,7 +2186,17 @@ click==7.1.2 ; python_version < "3.7" and python_version >= "3.6"
 click==8.0.3 ; {MARKER_PY37}
 """
 
-    assert io.fetch_output() == expected
+    expected = f"""\
+celery==5.1.2 ; {MARKER_PY36_ONLY}
+celery==5.2.3 ; {MARKER_PY37}
+click-didyoumean==0.0.3 ; {MARKER_PY36_PY362}
+click-didyoumean==0.3.0 ; {MARKER_PY362_PY40}
+click-plugins==1.1.1 ; {MARKER_PY36}
+click==7.1.2 ; {MARKER_PY36_ONLY}
+click==8.0.3 ; {MARKER_PY37}
+"""
+
+    assert io.fetch_output() in {expected, expected_legacy}
 
 
 def test_exporter_handles_extras_next_to_non_extras(
